@@ -1,17 +1,17 @@
-#' Check there are no files in the default `beautier` folder
+#' Deprecated function, use \link[beautier]{remove_beautier_folder}.
+#'
+#' Deprecated function, use \link[beautier]{remove_beautier_folder}.
 #'
 #' Check there are no files in the default `beautier` folder.
 #' The goal is to make sure no temporary files are left undeleted.
 #' Will \link{stop} if there are files in the `beautier` folder.
 #'
 #' @return Nothing.
-#' @examples
-#' remove_beautier_folder()
 #' @author Richèl J.C. Bilderbeek
 #' @export
 remove_beautier_folder <- function() {
-  folder_name <- beautier::get_beautier_folder()
-  if (dir.exists(folder_name)) {
-    unlink(folder_name, recursive = TRUE)
-  }
+  stop(
+    "'beastier::remove_beautier_folder' is deprecated, ",
+    "use 'beautier::remove_beautier_folder' instead"
+  )
 }
